/****************************************************************************
**
** Copyright (C) 2024 MikroElektronika d.o.o.
** Contact: https://www.mikroe.com/contact
**
** This file is part of the mikroSDK package
**
** Commercial License Usage
**
** Licensees holding valid commercial NECTO compilers AI licenses may use this
** file in accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The MikroElektronika Company.
** For licensing terms and conditions see
** https://www.mikroe.com/legal/software-license-agreement.
** For further information use the contact form at
** https://www.mikroe.com/contact.
**
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used for
** non-commercial projects under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** The above copyright notice and this permission notice shall be
** included in all copies or substantial portions of the Software.
**
** THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
** OF MERCHANTABILITY, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
** TO THE WARRANTIES FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
** IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
** DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
** OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
** OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
**
****************************************************************************/
/*!
 * @file  board.h
 * @brief Main board pin mapping.
 */

#ifndef _BOARD_H_
#define _BOARD_H_

#ifdef __cplusplus
extern "C"
{
#endif

// Hardware revision number
#define BOARD_REV_MAJOR (B)
#define BOARD_REV_MINOR (01)

#define BOARD_NAME "Nucleo-L433RC-P"

#include "hal_target.h"
#include "shield.h"

// Mapping
#define HEADER_CONNECTOR_CN1_D1  PC10 // Pin not routed.
#define HEADER_CONNECTOR_CN1_D2  PC11 // Pin not routed.
#define HEADER_CONNECTOR_CN1_D3  PC12
#define HEADER_CONNECTOR_CN1_D4       // Pin not routed.
#define HEADER_CONNECTOR_CN1_D5       // Pin not routed.
#define HEADER_CONNECTOR_CN1_D6       // Pin not routed.
#define HEADER_CONNECTOR_CN1_D7       // Pin not routed.
#define HEADER_CONNECTOR_CN1_D8       // Pin not routed.
#define HEADER_CONNECTOR_CN1_D9       // Pin not routed.
#define HEADER_CONNECTOR_CN1_D10      // Pin not routed.
#define HEADER_CONNECTOR_CN1_D11      // Pin not routed.
#define HEADER_CONNECTOR_CN1_D12      // Pin not routed.
#define HEADER_CONNECTOR_CN1_D13 PB12 // Pin not routed.
#define HEADER_CONNECTOR_CN1_D14      // Pin not routed.
#define HEADER_CONNECTOR_CN1_D15 PA13 // Pin not routed.
#define HEADER_CONNECTOR_CN1_D16      // Pin not routed.
#define HEADER_CONNECTOR_CN1_D17 PA14
#define HEADER_CONNECTOR_CN1_D18      // Pin not routed.
#define HEADER_CONNECTOR_CN1_D19      // Pin not routed.
#define HEADER_CONNECTOR_CN1_D20      // Pin not routed.
#define HEADER_CONNECTOR_CN1_D21      // Pin not routed.
#define HEADER_CONNECTOR_CN1_D22      // Pin not routed.
#define HEADER_CONNECTOR_CN1_D23 PC13 // Pin not routed.
#define HEADER_CONNECTOR_CN1_D24      // Pin not routed.
#define HEADER_CONNECTOR_CN1_D25 PC14
#define HEADER_CONNECTOR_CN1_D26      // Pin not routed.
#define HEADER_CONNECTOR_CN1_D27 PC15 // Pin not routed.
#define HEADER_CONNECTOR_CN1_D28 PA0  // Pin not routed.
#define HEADER_CONNECTOR_CN1_D29 PH0  // Pin not routed.
#define HEADER_CONNECTOR_CN1_D30 PA1  // Pin not routed.
#define HEADER_CONNECTOR_CN1_D31 PH1  // Pin not routed.
#define HEADER_CONNECTOR_CN1_D32 PC3  // Pin not routed.
#define HEADER_CONNECTOR_CN1_D33      // Pin not routed.
#define HEADER_CONNECTOR_CN1_D34 PC2  // Pin not routed.
#define HEADER_CONNECTOR_CN1_D35 PB4  // Pin not routed.
#define HEADER_CONNECTOR_CN1_D36 PC1
#define HEADER_CONNECTOR_CN1_D37 PB9  // Pin not routed.
#define HEADER_CONNECTOR_CN1_D38 PC0

#define HEADER_CONNECTOR_CN2_D1  PC9
#define HEADER_CONNECTOR_CN2_D2       // Pin not routed.
#define HEADER_CONNECTOR_CN2_D3  PB8
#define HEADER_CONNECTOR_CN2_D4       // Pin not routed.
#define HEADER_CONNECTOR_CN2_D5  PB7
#define HEADER_CONNECTOR_CN2_D6  PC5  // Pin not routed.
#define HEADER_CONNECTOR_CN2_D7       // Pin not routed.
#define HEADER_CONNECTOR_CN2_D8       // Pin not routed.
#define HEADER_CONNECTOR_CN2_D9       // Pin not routed.
#define HEADER_CONNECTOR_CN2_D10 PB0  // Pin not routed.
#define HEADER_CONNECTOR_CN2_D11 PB13 // Pin not routed.
#define HEADER_CONNECTOR_CN2_D12 PA10 // Pin not routed.
#define HEADER_CONNECTOR_CN2_D13 PB14 // Pin not routed.
#define HEADER_CONNECTOR_CN2_D14 PA9  // Pin not routed.
#define HEADER_CONNECTOR_CN2_D15 PB15 // Pin not routed.
#define HEADER_CONNECTOR_CN2_D16 PB11
#define HEADER_CONNECTOR_CN2_D17      // Pin not routed.
#define HEADER_CONNECTOR_CN2_D18 PB2  // Pin not routed.
#define HEADER_CONNECTOR_CN2_D19 PA8  // Pin not routed.
#define HEADER_CONNECTOR_CN2_D20      // Pin not routed.
#define HEADER_CONNECTOR_CN2_D21 PB6  // Pin not routed.
#define HEADER_CONNECTOR_CN2_D22 PB1  // Pin not routed.
#define HEADER_CONNECTOR_CN2_D23 PC7  // Pin not routed.
#define HEADER_CONNECTOR_CN2_D24 PA7  // Pin not routed.
#define HEADER_CONNECTOR_CN2_D25 PB10 // Pin not routed.
#define HEADER_CONNECTOR_CN2_D26 PA6  // Pin not routed.
#define HEADER_CONNECTOR_CN2_D27      // Pin not routed.
#define HEADER_CONNECTOR_CN2_D28 PA5  // Pin not routed.
#define HEADER_CONNECTOR_CN2_D29 PB5
#define HEADER_CONNECTOR_CN2_D30 PA4  // Pin not routed.
#define HEADER_CONNECTOR_CN2_D31 PB3
#define HEADER_CONNECTOR_CN2_D32      // Pin not routed.
#define HEADER_CONNECTOR_CN2_D33      // Pin not routed.
#define HEADER_CONNECTOR_CN2_D34 PC4  // Pin not routed.
#define HEADER_CONNECTOR_CN2_D35 PA9
#define HEADER_CONNECTOR_CN2_D36 PA3  // Pin not routed.
#define HEADER_CONNECTOR_CN2_D37 PA10
#define HEADER_CONNECTOR_CN2_D38 PA2  // Pin not routed.

#ifdef __cplusplus
}
#endif

#endif    // _BOARD_H_
// ------------------------------------------------------------------------- END
