/****************************************************************************
**
** Copyright (C) 2024 MikroElektronika d.o.o.
** Contact: https://www.mikroe.com/contact
**
** This file is part of the mikroSDK package
**
** Commercial License Usage
**
** Licensees holding valid commercial NECTO compilers AI licenses may use this
** file in accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The MikroElektronika Company.
** For licensing terms and conditions see
** https://www.mikroe.com/legal/software-license-agreement.
** For further information use the contact form at
** https://www.mikroe.com/contact.
**
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used for
** non-commercial projects under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** The above copyright notice and this permission notice shall be
** included in all copies or substantial portions of the Software.
**
** THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
** OF MERCHANTABILITY, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
** TO THE WARRANTIES FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
** IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
** DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
** OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
** OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
**
****************************************************************************/
/*!
 * @file  shield.h
 * @brief Arduino Uno Rev3 shield connections mapping.
 */

#ifndef _SHIELD_H_
#define _SHIELD_H_

#ifdef __cplusplus
extern "C"{
#endif

#include "mikrobus.h"

// Shield header connections
#define SHIELD_CONNECTOR_HD1_PIN1 HEADER_CONNECTOR_D14
#define SHIELD_CONNECTOR_HD1_PIN2 HEADER_CONNECTOR_D15
#define SHIELD_CONNECTOR_HD1_PIN3 HEADER_CONNECTOR_D16
#define SHIELD_CONNECTOR_HD1_PIN4 HEADER_CONNECTOR_D17
#define SHIELD_CONNECTOR_HD1_PIN5 HEADER_CONNECTOR_D18
#define SHIELD_CONNECTOR_HD1_PIN6 HEADER_CONNECTOR_D19

#define SHIELD_CONNECTOR_HD3_PIN2 HEADER_CONNECTOR_D6
#define SHIELD_CONNECTOR_HD3_PIN3 HEADER_CONNECTOR_D5
#define SHIELD_CONNECTOR_HD3_PIN5 HEADER_CONNECTOR_D3
#define SHIELD_CONNECTOR_HD3_PIN6 HEADER_CONNECTOR_D2
#define SHIELD_CONNECTOR_HD3_PIN7 HEADER_CONNECTOR_D1
#define SHIELD_CONNECTOR_HD3_PIN8 HEADER_CONNECTOR_D0

#define SHIELD_CONNECTOR_HD4_PIN5 HEADER_CONNECTOR_D13
#define SHIELD_CONNECTOR_HD4_PIN6 HEADER_CONNECTOR_D12
#define SHIELD_CONNECTOR_HD4_PIN7 HEADER_CONNECTOR_D11
#define SHIELD_CONNECTOR_HD4_PIN8 HEADER_CONNECTOR_D10
#define SHIELD_CONNECTOR_HD4_PIN9 HEADER_CONNECTOR_D9

#define SHIELD_SW1_TX HEADER_CONNECTOR_D1
#define SHIELD_SW1_RX HEADER_CONNECTOR_D0

// MikroBUS definitions
#define SHIELD_MIKROBUS_1_AN   SHIELD_CONNECTOR_HD1_PIN1
#define SHIELD_MIKROBUS_1_RST  SHIELD_CONNECTOR_HD1_PIN4
#define SHIELD_MIKROBUS_1_CS   SHIELD_CONNECTOR_HD4_PIN8
#define SHIELD_MIKROBUS_1_SCK  SHIELD_CONNECTOR_HD4_PIN5
#define SHIELD_MIKROBUS_1_MISO SHIELD_CONNECTOR_HD4_PIN6
#define SHIELD_MIKROBUS_1_MOSI SHIELD_CONNECTOR_HD4_PIN7
#define SHIELD_MIKROBUS_1_PWM  SHIELD_CONNECTOR_HD3_PIN2
#define SHIELD_MIKROBUS_1_INT  SHIELD_CONNECTOR_HD3_PIN6
#define SHIELD_MIKROBUS_1_RX   SHIELD_SW1_RX
#define SHIELD_MIKROBUS_1_TX   SHIELD_SW1_TX
#define SHIELD_MIKROBUS_1_SCL  SHIELD_CONNECTOR_HD1_PIN6
#define SHIELD_MIKROBUS_1_SDA  SHIELD_CONNECTOR_HD1_PIN5

#define SHIELD_MIKROBUS_2_AN   SHIELD_CONNECTOR_HD1_PIN2
#define SHIELD_MIKROBUS_2_RST  SHIELD_CONNECTOR_HD1_PIN3
#define SHIELD_MIKROBUS_2_CS   SHIELD_CONNECTOR_HD4_PIN9
#define SHIELD_MIKROBUS_2_SCK  SHIELD_CONNECTOR_HD4_PIN5
#define SHIELD_MIKROBUS_2_MISO SHIELD_CONNECTOR_HD4_PIN6
#define SHIELD_MIKROBUS_2_MOSI SHIELD_CONNECTOR_HD4_PIN7
#define SHIELD_MIKROBUS_2_PWM  SHIELD_CONNECTOR_HD3_PIN3
#define SHIELD_MIKROBUS_2_INT  SHIELD_CONNECTOR_HD3_PIN5
#define SHIELD_MIKROBUS_2_RX   SHIELD_SW1_RX
#define SHIELD_MIKROBUS_2_TX   SHIELD_SW1_TX
#define SHIELD_MIKROBUS_2_SCL  SHIELD_CONNECTOR_HD1_PIN6
#define SHIELD_MIKROBUS_2_SDA  SHIELD_CONNECTOR_HD1_PIN5

#define MIKROBUS_1 1
#define MIKROBUS_1_AN   SHIELD_MIKROBUS_1_AN
#define MIKROBUS_1_RST  SHIELD_MIKROBUS_1_RST
#define MIKROBUS_1_CS   SHIELD_MIKROBUS_1_CS
#define MIKROBUS_1_SCK  SHIELD_MIKROBUS_1_SCK
#define MIKROBUS_1_MISO SHIELD_MIKROBUS_1_MISO
#define MIKROBUS_1_MOSI SHIELD_MIKROBUS_1_MOSI
#define MIKROBUS_1_PWM  SHIELD_MIKROBUS_1_PWM
#define MIKROBUS_1_RX   SHIELD_MIKROBUS_1_RX
#define MIKROBUS_1_INT  SHIELD_MIKROBUS_1_INT
#define MIKROBUS_1_TX   SHIELD_MIKROBUS_1_TX
#define MIKROBUS_1_SCL  SHIELD_MIKROBUS_1_SCL
#define MIKROBUS_1_SDA  SHIELD_MIKROBUS_1_SDA

#define MIKROBUS_2 2
#define MIKROBUS_2_AN   SHIELD_MIKROBUS_2_AN
#define MIKROBUS_2_RST  SHIELD_MIKROBUS_2_RST
#define MIKROBUS_2_CS   SHIELD_MIKROBUS_2_CS
#define MIKROBUS_2_SCK  SHIELD_MIKROBUS_2_SCK
#define MIKROBUS_2_MISO SHIELD_MIKROBUS_2_MISO
#define MIKROBUS_2_MOSI SHIELD_MIKROBUS_2_MOSI
#define MIKROBUS_2_PWM  SHIELD_MIKROBUS_2_PWM
#define MIKROBUS_2_RX   SHIELD_MIKROBUS_2_RX
#define MIKROBUS_2_INT  SHIELD_MIKROBUS_2_INT
#define MIKROBUS_2_TX   SHIELD_MIKROBUS_2_TX
#define MIKROBUS_2_SCL  SHIELD_MIKROBUS_2_SCL
#define MIKROBUS_2_SDA  SHIELD_MIKROBUS_2_SDA

#ifdef __cplusplus
}
#endif

#endif // _SHIELD_H_
// ------------------------------------------------------------------------- END
