/****************************************************************************
**
** Copyright (C) 2024 MikroElektronika d.o.o.
** Contact: https://www.mikroe.com/contact
**
** This file is part of the mikroSDK package
**
** Commercial License Usage
**
** Licensees holding valid commercial NECTO compilers AI licenses may use this
** file in accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The MikroElektronika Company.
** For licensing terms and conditions see
** https://www.mikroe.com/legal/software-license-agreement.
** For further information use the contact form at
** https://www.mikroe.com/contact.
**
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used for
** non-commercial projects under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** The above copyright notice and this permission notice shall be
** included in all copies or substantial portions of the Software.
**
** THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
** OF MERCHANTABILITY, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
** TO THE WARRANTIES FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
** IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
** DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
** OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
** OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
**
****************************************************************************/
/*!
 * @file  shield.h
 * @brief STM32F4_DISCOVERY shield connections mapping.
 */

#ifndef _SHIELD_H_
#define _SHIELD_H_

#ifdef __cplusplus
extern "C"{
#endif

#include "mikrobus.h"

// Shield header connections
#define SHIELD_CONNECTOR_P1_PIN7  HEADER_CONNECTOR_CN1_D7
#define SHIELD_CONNECTOR_P1_PIN28 HEADER_CONNECTOR_CN1_D28
#define SHIELD_CONNECTOR_P1_PIN36 HEADER_CONNECTOR_CN1_D36
#define SHIELD_CONNECTOR_P1_PIN37 HEADER_CONNECTOR_CN1_D37
#define SHIELD_CONNECTOR_P1_PIN38 HEADER_CONNECTOR_CN1_D38
#define SHIELD_CONNECTOR_P1_PIN39 HEADER_CONNECTOR_CN1_D39
#define SHIELD_CONNECTOR_P1_PIN11 HEADER_CONNECTOR_CN1_D11
#define SHIELD_CONNECTOR_P1_PIN25 HEADER_CONNECTOR_CN1_D25
#define SHIELD_CONNECTOR_P1_PIN35 HEADER_CONNECTOR_CN1_D35
#define SHIELD_CONNECTOR_P1_PIN34 HEADER_CONNECTOR_CN1_D34
#define SHIELD_CONNECTOR_P2_PIN19 HEADER_CONNECTOR_CN2_D19
#define SHIELD_CONNECTOR_P2_PIN24 HEADER_CONNECTOR_CN2_D24

#define SHIELD_CONNECTOR_P1_PIN10 HEADER_CONNECTOR_CN1_D10
#define SHIELD_CONNECTOR_P1_PIN30 HEADER_CONNECTOR_CN1_D30
#define SHIELD_CONNECTOR_P1_PIN32 HEADER_CONNECTOR_CN1_D32
#define SHIELD_CONNECTOR_P1_PIN31 HEADER_CONNECTOR_CN1_D31
#define SHIELD_CONNECTOR_P1_PIN26 HEADER_CONNECTOR_CN1_D26

#define SHIELD_CONNECTOR_P1_PIN19 HEADER_CONNECTOR_CN1_D19
#define SHIELD_CONNECTOR_P2_PIN13 HEADER_CONNECTOR_CN2_D13
#define SHIELD_CONNECTOR_P2_PIN14 HEADER_CONNECTOR_CN2_D14
#define SHIELD_CONNECTOR_P2_PIN28 HEADER_CONNECTOR_CN2_D28
#define SHIELD_CONNECTOR_P2_PIN25 HEADER_CONNECTOR_CN2_D25
#define SHIELD_CONNECTOR_P2_PIN26 HEADER_CONNECTOR_CN2_D26
#define SHIELD_CONNECTOR_P1_PIN21 HEADER_CONNECTOR_CN1_D21
#define SHIELD_CONNECTOR_P2_PIN34 HEADER_CONNECTOR_CN2_D34
#define SHIELD_CONNECTOR_P2_PIN48 HEADER_CONNECTOR_CN2_D48
#define SHIELD_CONNECTOR_P2_PIN47 HEADER_CONNECTOR_CN2_D47
#define SHIELD_CONNECTOR_P2_PIN43 HEADER_CONNECTOR_CN2_D43
#define SHIELD_CONNECTOR_P2_PIN46 HEADER_CONNECTOR_CN2_D46

#define SHIELD_CONNECTOR_P1_PIN22 HEADER_CONNECTOR_CN1_D22
#define SHIELD_CONNECTOR_P2_PIN30 HEADER_CONNECTOR_CN2_D30
#define SHIELD_CONNECTOR_P2_PIN27 HEADER_CONNECTOR_CN2_D27
#define SHIELD_CONNECTOR_P2_PIN45 HEADER_CONNECTOR_CN2_D45
#define SHIELD_CONNECTOR_P2_PIN38 HEADER_CONNECTOR_CN2_D38

// MikroBUS definitions
#define SHIELD_MIKROBUS_1_AN   SHIELD_CONNECTOR_P1_PIN7
#define SHIELD_MIKROBUS_1_RST  SHIELD_CONNECTOR_P1_PIN28
#define SHIELD_MIKROBUS_1_CS   SHIELD_CONNECTOR_P1_PIN36
#define SHIELD_MIKROBUS_1_SCK  SHIELD_CONNECTOR_P1_PIN37
#define SHIELD_MIKROBUS_1_MISO SHIELD_CONNECTOR_P1_PIN38
#define SHIELD_MIKROBUS_1_MOSI SHIELD_CONNECTOR_P1_PIN39
#define SHIELD_MIKROBUS_1_PWM  SHIELD_CONNECTOR_P1_PIN11
#define SHIELD_MIKROBUS_1_INT  SHIELD_CONNECTOR_P1_PIN25
#define SHIELD_MIKROBUS_1_RX   SHIELD_CONNECTOR_P1_PIN35
#define SHIELD_MIKROBUS_1_TX   SHIELD_CONNECTOR_P1_PIN34
#define SHIELD_MIKROBUS_1_SCL  SHIELD_CONNECTOR_P2_PIN19
#define SHIELD_MIKROBUS_1_SDA  SHIELD_CONNECTOR_P2_PIN24

#define SHIELD_MIKROBUS_2_AN   SHIELD_CONNECTOR_P1_PIN10
#define SHIELD_MIKROBUS_2_RST  SHIELD_CONNECTOR_P1_PIN30
#define SHIELD_MIKROBUS_2_CS   SHIELD_CONNECTOR_P1_PIN32
#define SHIELD_MIKROBUS_2_SCK  SHIELD_CONNECTOR_P1_PIN37
#define SHIELD_MIKROBUS_2_MISO SHIELD_CONNECTOR_P1_PIN38
#define SHIELD_MIKROBUS_2_MOSI SHIELD_CONNECTOR_P1_PIN39
#define SHIELD_MIKROBUS_2_PWM  SHIELD_CONNECTOR_P1_PIN31
#define SHIELD_MIKROBUS_2_INT  SHIELD_CONNECTOR_P1_PIN26
#define SHIELD_MIKROBUS_2_RX   SHIELD_CONNECTOR_P1_PIN35
#define SHIELD_MIKROBUS_2_TX   SHIELD_CONNECTOR_P1_PIN34
#define SHIELD_MIKROBUS_2_SCL  SHIELD_CONNECTOR_P2_PIN19
#define SHIELD_MIKROBUS_2_SDA  SHIELD_CONNECTOR_P2_PIN24

#define SHIELD_MIKROBUS_3_AN   SHIELD_CONNECTOR_P1_PIN19
#define SHIELD_MIKROBUS_3_RST  SHIELD_CONNECTOR_P2_PIN13
#define SHIELD_MIKROBUS_3_CS   SHIELD_CONNECTOR_P2_PIN14
#define SHIELD_MIKROBUS_3_SCK  SHIELD_CONNECTOR_P2_PIN28
#define SHIELD_MIKROBUS_3_MISO SHIELD_CONNECTOR_P2_PIN25
#define SHIELD_MIKROBUS_3_MOSI SHIELD_CONNECTOR_P2_PIN26
#define SHIELD_MIKROBUS_3_PWM  SHIELD_CONNECTOR_P1_PIN21
#define SHIELD_MIKROBUS_3_INT  SHIELD_CONNECTOR_P2_PIN34
#define SHIELD_MIKROBUS_3_RX   SHIELD_CONNECTOR_P2_PIN48
#define SHIELD_MIKROBUS_3_TX   SHIELD_CONNECTOR_P2_PIN47
#define SHIELD_MIKROBUS_3_SCL  SHIELD_CONNECTOR_P2_PIN43
#define SHIELD_MIKROBUS_3_SDA  SHIELD_CONNECTOR_P2_PIN46

#define SHIELD_MIKROBUS_4_AN   SHIELD_CONNECTOR_P1_PIN22
#define SHIELD_MIKROBUS_4_RST  SHIELD_CONNECTOR_P2_PIN30
#define SHIELD_MIKROBUS_4_CS   SHIELD_CONNECTOR_P2_PIN27
#define SHIELD_MIKROBUS_4_SCK  SHIELD_CONNECTOR_P2_PIN28
#define SHIELD_MIKROBUS_4_MISO SHIELD_CONNECTOR_P2_PIN25
#define SHIELD_MIKROBUS_4_MOSI SHIELD_CONNECTOR_P2_PIN26
#define SHIELD_MIKROBUS_4_PWM  SHIELD_CONNECTOR_P2_PIN45
#define SHIELD_MIKROBUS_4_INT  SHIELD_CONNECTOR_P2_PIN38
#define SHIELD_MIKROBUS_4_RX   SHIELD_CONNECTOR_P2_PIN48
#define SHIELD_MIKROBUS_4_TX   SHIELD_CONNECTOR_P2_PIN47
#define SHIELD_MIKROBUS_4_SCL  SHIELD_CONNECTOR_P2_PIN43
#define SHIELD_MIKROBUS_4_SDA  SHIELD_CONNECTOR_P2_PIN46

#define MIKROBUS_1 1
#define MIKROBUS_1_AN   SHIELD_MIKROBUS_1_AN
#define MIKROBUS_1_RST  SHIELD_MIKROBUS_1_RST
#define MIKROBUS_1_CS   SHIELD_MIKROBUS_1_CS
#define MIKROBUS_1_SCK  SHIELD_MIKROBUS_1_SCK
#define MIKROBUS_1_MISO SHIELD_MIKROBUS_1_MISO
#define MIKROBUS_1_MOSI SHIELD_MIKROBUS_1_MOSI
#define MIKROBUS_1_PWM  SHIELD_MIKROBUS_1_PWM
#define MIKROBUS_1_RX   SHIELD_MIKROBUS_1_RX
#define MIKROBUS_1_INT  SHIELD_MIKROBUS_1_INT
#define MIKROBUS_1_TX   SHIELD_MIKROBUS_1_TX
#define MIKROBUS_1_SCL  SHIELD_MIKROBUS_1_SCL
#define MIKROBUS_1_SDA  SHIELD_MIKROBUS_1_SDA

#define MIKROBUS_2 2
#define MIKROBUS_2_AN   SHIELD_MIKROBUS_2_AN
#define MIKROBUS_2_RST  SHIELD_MIKROBUS_2_RST
#define MIKROBUS_2_CS   SHIELD_MIKROBUS_2_CS
#define MIKROBUS_2_SCK  SHIELD_MIKROBUS_2_SCK
#define MIKROBUS_2_MISO SHIELD_MIKROBUS_2_MISO
#define MIKROBUS_2_MOSI SHIELD_MIKROBUS_2_MOSI
#define MIKROBUS_2_PWM  SHIELD_MIKROBUS_2_PWM
#define MIKROBUS_2_RX   SHIELD_MIKROBUS_2_RX
#define MIKROBUS_2_INT  SHIELD_MIKROBUS_2_INT
#define MIKROBUS_2_TX   SHIELD_MIKROBUS_2_TX
#define MIKROBUS_2_SCL  SHIELD_MIKROBUS_2_SCL
#define MIKROBUS_2_SDA  SHIELD_MIKROBUS_2_SDA

#define MIKROBUS_3 3
#define MIKROBUS_3_AN   SHIELD_MIKROBUS_3_AN
#define MIKROBUS_3_RST  SHIELD_MIKROBUS_3_RST
#define MIKROBUS_3_CS   SHIELD_MIKROBUS_3_CS
#define MIKROBUS_3_SCK  SHIELD_MIKROBUS_3_SCK
#define MIKROBUS_3_MISO SHIELD_MIKROBUS_3_MISO
#define MIKROBUS_3_MOSI SHIELD_MIKROBUS_3_MOSI
#define MIKROBUS_3_PWM  SHIELD_MIKROBUS_3_PWM
#define MIKROBUS_3_RX   SHIELD_MIKROBUS_3_RX
#define MIKROBUS_3_INT  SHIELD_MIKROBUS_3_INT
#define MIKROBUS_3_TX   SHIELD_MIKROBUS_3_TX
#define MIKROBUS_3_SCL  SHIELD_MIKROBUS_3_SCL
#define MIKROBUS_3_SDA  SHIELD_MIKROBUS_3_SDA

#define MIKROBUS_4 4
#define MIKROBUS_4_AN   SHIELD_MIKROBUS_4_AN
#define MIKROBUS_4_RST  SHIELD_MIKROBUS_4_RST
#define MIKROBUS_4_CS   SHIELD_MIKROBUS_4_CS
#define MIKROBUS_4_SCK  SHIELD_MIKROBUS_4_SCK
#define MIKROBUS_4_MISO SHIELD_MIKROBUS_4_MISO
#define MIKROBUS_4_MOSI SHIELD_MIKROBUS_4_MOSI
#define MIKROBUS_4_PWM  SHIELD_MIKROBUS_4_PWM
#define MIKROBUS_4_RX   SHIELD_MIKROBUS_4_RX
#define MIKROBUS_4_INT  SHIELD_MIKROBUS_4_INT
#define MIKROBUS_4_TX   SHIELD_MIKROBUS_4_TX
#define MIKROBUS_4_SCL  SHIELD_MIKROBUS_4_SCL
#define MIKROBUS_4_SDA  SHIELD_MIKROBUS_4_SDA

#ifdef __cplusplus
}
#endif

#endif // _SHIELD_H_
// ------------------------------------------------------------------------- END