/****************************************************************************
**
** Copyright (C) 2024 MikroElektronika d.o.o.
** Contact: https://www.mikroe.com/contact
**
** This file is part of the mikroSDK package
**
** Commercial License Usage
**
** Licensees holding valid commercial NECTO compilers AI licenses may use this
** file in accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The MikroElektronika Company.
** For licensing terms and conditions see
** https://www.mikroe.com/legal/software-license-agreement.
** For further information use the contact form at
** https://www.mikroe.com/contact.
**
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used for
** non-commercial projects under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** The above copyright notice and this permission notice shall be
** included in all copies or substantial portions of the Software.
**
** THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
** OF MERCHANTABILITY, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
** TO THE WARRANTIES FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
** IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
** DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
** OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
** OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
**
****************************************************************************/
/*!
 * @file  hal_ll_pps_connection_defs.h
 * @brief This file contains pps maps per chip for LOW LEVEL HAL PPS
 *        implementation for PIC24FJ256GB606.
 */

#ifndef _HAL_LL_PPS_CONNECTION_DEFS_H_
#define _HAL_LL_PPS_CONNECTION_DEFS_H_

#ifdef __cplusplus
extern "C"
{
#endif

#include "hal_ll_pps_struct_def.h"

/**
 * NOTE:
 * This macro is used for pins that do not have adequate PPS
 * registers according to datasheet.
 */
#define INVALID_PPS_ADDRESS (0) // TODO

// -------------------------------------------------------------

/*!< @brief PPS INPUT FUNCTIONS */
static const hal_ll_pps_pin_map_t hal_ll_pps_input_map[] =
{
    #ifdef UART1_RX_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 1, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 14, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 29, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 13, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 28, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 18, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 6, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 7, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 8, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 9, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RC14_RPI37
    {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 37, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 11, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 24, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 3, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 12, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 23, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 22, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 25, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 20, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 2, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 4, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 16, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 10, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 17, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 21, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 26, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 19, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 27, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 1, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 14, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 29, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 13, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 28, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 18, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 6, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 7, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 8, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 9, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RC14_RPI37
    {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 37, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 11, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 24, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 3, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 12, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 23, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 22, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 25, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 20, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 2, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 4, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 16, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 10, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 17, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 21, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 26, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 19, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 27, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 1, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 14, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 29, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 13, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 28, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 18, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 6, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 7, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 8, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 9, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RC14_RPI37
    {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 37, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 11, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 24, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 3, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 12, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 23, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 22, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 25, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 20, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 2, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 4, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 16, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 10, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 17, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 21, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 26, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 19, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 27, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR17_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 1, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 14, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 29, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 13, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 28, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 18, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 6, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 7, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 8, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 9, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RC14_RPI37
    {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 37, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 11, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 24, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 3, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 12, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 23, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 22, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 25, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 20, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 2, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 4, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 16, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 10, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 17, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 21, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 26, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 19, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 27, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 1, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 14, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 29, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 13, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 28, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 18, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 6, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 7, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 8, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 9, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RC14_RPI37
    {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 37, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 11, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 24, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 3, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 12, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 23, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 22, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 25, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 20, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 2, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 4, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 16, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 10, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 17, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 21, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 26, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 19, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 27, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 1, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 14, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 29, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 13, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 28, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 18, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 6, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 7, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 8, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 9, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RC14_RPI37
    {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 37, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 11, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 24, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 3, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 12, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 23, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 22, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 25, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 20, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 2, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 4, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 16, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 10, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 17, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 21, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 26, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 19, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 27, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR22_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 0, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 1, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 14, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 29, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 13, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 28, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 18, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 6, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 7, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 8, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 9, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RC14_RPI37
    {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 37, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 11, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 24, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 3, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 12, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 23, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 22, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 25, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 20, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 2, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 4, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 16, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 10, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 17, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 21, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 26, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 19, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 27, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR28_REG_ADDRESS},
    #endif

    { HAL_LL_PIN_NC, HAL_LL_PORT_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_MODULE_ERROR, HAL_LL_MODULE_ERROR }
};

/*!< @brief PPS OUTPUT FUNCTIONS */
static const hal_ll_pps_pin_map_t hal_ll_pps_output_map[] =
{
    #ifdef UART1_TX_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0005, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0013, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0015ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0015ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0015ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0015ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0015ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0015ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0015ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0015ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0015ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0015ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0015ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0015, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0015ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0015ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0007ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0007ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0007ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0007ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0007ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0007ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0007ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0007ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0007ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0007ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0007ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0007, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0007ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0007ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0008, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x000Aul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x000Aul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x000Aul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x000Aul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x000Aul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x000Aul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x000Aul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x000Aul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x000Aul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x000Aul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x000Aul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x000A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x000Aul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x000Aul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x000Bul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x000Bul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x000Bul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x000Bul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x000Bul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x000Bul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x000Bul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x000Bul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x000Bul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x000Bul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x000Bul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x000B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x000Bul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x000Bul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0017, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0018ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0018ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0018ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0018ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0018ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0018ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0018ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0018ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0018ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0018ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0018ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0018, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0018ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0018ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC1_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x000D, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC1_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x000Dul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC1_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x000D, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC1_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x000D, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC2_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x000E, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC3_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x000F, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC5_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0011, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC5_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0011ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC5_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0011ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC6_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0012ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC6_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0012ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC1_RD1_RP24
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x000D, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC2_RD0_RP11
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x000Eul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC2_RD9_RP4
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x000E, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC3_RD11_RP12
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x000F, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC3_RD4_RP25
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x000Ful << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR12_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC4_RD2_RP23
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0010ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC4_RD8_RP2
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0010, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC5_RD10_RP3
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0011ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC6_RD3_RP22
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0012, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR11_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC6_RD5_RP20
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0012, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP3_OC3_RF3_RP16
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x000F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP3_OC3_RF4_RP10
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x000F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP3_OC6_RF5_RP17
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0012ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP4_OC1_RG9_RP27
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x000Dul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP4_OC2_RG8_RP19
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x000Eul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP4_OC4_RG7_RP26
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0010, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP4_OC5_RG6_RP21
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0011ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC1_RB1_RP1
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x000Dul << 8), HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC1_RB9_RP9
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x000Dul << 8), HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC2_RB0_RP0
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x000E, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC2_RB2_RP13
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x000Eul << 8), HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC2_RB4_RP28
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x000E, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC2_RB5_RP18
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x000E, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC3_RB6_RP6
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x000F, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC4_RB8_RP8
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0010, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC6_RB14_RP14
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0012, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC6_RB15_RP29
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0012ul << 8), HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC6_RB7_RP7
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0012ul << 8), HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR3_REG_ADDRESS},
    #endif

    { HAL_LL_PIN_NC, HAL_LL_PORT_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_MODULE_ERROR, HAL_LL_MODULE_ERROR }
};

#ifdef __cplusplus
}
#endif

#endif // _HAL_LL_PPS_CONNECTION_DEFS_H_
// ------------------------------------------------------------------------- END
