/****************************************************************************
**
** Copyright (C) 2024 MikroElektronika d.o.o.
** Contact: https://www.mikroe.com/contact
**
** This file is part of the mikroSDK package
**
** Commercial License Usage
**
** Licensees holding valid commercial NECTO compilers AI licenses may use this
** file in accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The MikroElektronika Company.
** For licensing terms and conditions see
** https://www.mikroe.com/legal/software-license-agreement.
** For further information use the contact form at
** https://www.mikroe.com/contact.
**
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used for
** non-commercial projects under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** The above copyright notice and this permission notice shall be
** included in all copies or substantial portions of the Software.
**
** THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
** OF MERCHANTABILITY, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
** TO THE WARRANTIES FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
** IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
** DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
** OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
** OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
**
****************************************************************************/
/*!
 * @file  hal_ll_pps_connection_defs.h
 * @brief This file contains pps maps per chip for LOW LEVEL HAL PPS implementation.
 */

#ifndef _HAL_LL_PPS_CONNECTION_DEFS_H_
#define _HAL_LL_PPS_CONNECTION_DEFS_H_

#ifdef __cplusplus
extern "C"
{
#endif

#include "hal_ll_pps_struct_def.h"

// -------------------------------------------------------------

/*!< @brief PPS INPUT FUNCTIONS */
static const hal_ll_pps_pin_map_t hal_ll_pps_input_map[] =
{
    #ifdef __RD2_CN
    #ifdef HAL_LL_U1RXR_ADDRESS
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x00, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_U1RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U2RXR_ADDRESS
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x00, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_U2RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI3R_ADDRESS
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x00, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_SDI3R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI4R_ADDRESS
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x00, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_SDI4R_ADDRESS },
    #endif
    #endif
    #ifdef __RG8_CN
    #ifdef HAL_LL_U1RXR_ADDRESS
    { PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_U1RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U2RXR_ADDRESS
    { PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x01, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_U2RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI3R_ADDRESS
    { PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_SDI3R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI4R_ADDRESS
    { PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x01, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_SDI4R_ADDRESS },
    #endif
    #endif
    #ifdef __RF4_CN
    #ifdef HAL_LL_U1RXR_ADDRESS
    { PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x02, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_U1RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U2RXR_ADDRESS
    { PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x02, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_U2RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI3R_ADDRESS
    { PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x02, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_SDI3R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI4R_ADDRESS
    { PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_SDI4R_ADDRESS },
    #endif
    #endif
    #ifdef __RD10_CN
    #ifdef HAL_LL_U1RXR_ADDRESS
    { PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x03, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_U1RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U2RXR_ADDRESS
    { PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_U2RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI3R_ADDRESS
    { PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x03, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_SDI3R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI4R_ADDRESS
    { PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x03, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_SDI4R_ADDRESS },
    #endif
    #endif
    #ifdef __RF1_CN
    #ifdef HAL_LL_U1RXR_ADDRESS
    { PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x04, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_U1RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U2RXR_ADDRESS
    { PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_U2RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI3R_ADDRESS
    { PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x04, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_SDI3R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI4R_ADDRESS
    { PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x04, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_SDI4R_ADDRESS },
    #endif
    #endif
    #ifdef __RB9_CN
    #ifdef HAL_LL_U1RXR_ADDRESS
    { PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x05, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_U1RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U2RXR_ADDRESS
    { PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_U2RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI3R_ADDRESS
    { PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x05, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_SDI3R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI4R_ADDRESS
    { PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x05, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_SDI4R_ADDRESS },
    #endif
    #endif
    #ifdef __RB10_CN
    #ifdef HAL_LL_U1RXR_ADDRESS
    { PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x06, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_U1RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U2RXR_ADDRESS
    { PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_U2RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI3R_ADDRESS
    { PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x06, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_SDI3R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI4R_ADDRESS
    { PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x06, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_SDI4R_ADDRESS },
    #endif
    #endif
    #ifdef __RC14_CN
    #ifdef HAL_LL_U1RXR_ADDRESS
    { PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x07, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_U1RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U2RXR_ADDRESS
    { PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x07, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_U2RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI3R_ADDRESS
    { PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x07, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_SDI3R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI4R_ADDRESS
    { PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x07, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_SDI4R_ADDRESS },
    #endif
    #endif
    #ifdef __RB5_CN
    #ifdef HAL_LL_U1RXR_ADDRESS
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_U1RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U2RXR_ADDRESS
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x08, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_U2RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI3R_ADDRESS
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_SDI3R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI4R_ADDRESS
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x08, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_SDI4R_ADDRESS },
    #endif
    #endif
    #ifdef __RC1_CN
    #ifdef HAL_LL_U1RXR_ADDRESS
    { PIN_1, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0A, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_U1RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U2RXR_ADDRESS
    { PIN_1, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_U2RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI3R_ADDRESS
    { PIN_1, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0A, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_SDI3R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI4R_ADDRESS
    { PIN_1, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0A, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_SDI4R_ADDRESS },
    #endif
    #endif
    #ifdef __RD14_CN
    #ifdef HAL_LL_U1RXR_ADDRESS
    { PIN_14, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0B, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_U1RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U2RXR_ADDRESS
    { PIN_14, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_U2RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI3R_ADDRESS
    { PIN_14, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_SDI3R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI4R_ADDRESS
    { PIN_14, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_SDI4R_ADDRESS },
    #endif
    #endif
    #ifdef __RG1_CN
    #ifdef HAL_LL_U1RXR_ADDRESS
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_U1RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U2RXR_ADDRESS
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0C, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_U2RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI3R_ADDRESS
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0C, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_SDI3R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI4R_ADDRESS
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0C, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_SDI4R_ADDRESS },
    #endif
    #endif
    #ifdef __RA14_CN
    #ifdef HAL_LL_U1RXR_ADDRESS
    { PIN_14, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0D, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_U1RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U2RXR_ADDRESS
    { PIN_14, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0D, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_U2RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI3R_ADDRESS
    { PIN_14, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0D, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_SDI3R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI4R_ADDRESS
    { PIN_14, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0D, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_SDI4R_ADDRESS },
    #endif
    #endif
    #ifdef __RF2_CN
    #ifdef HAL_LL_U1RXR_ADDRESS
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0F, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_U1RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U2RXR_ADDRESS
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0F, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_U2RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI3R_ADDRESS
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_SDI3R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI4R_ADDRESS
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_SDI4R_ADDRESS },
    #endif

    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0E, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0E, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif

    #ifdef __RD3_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x00, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x00, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x00, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif
    #ifdef __RG7_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x01, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif
    #ifdef __RF5_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x02, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x02, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x02, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif
    #ifdef __RD11_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x03, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x03, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif
    #ifdef __RF0_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x04, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x04, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x04, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif
    #ifdef __RB1_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x05, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x05, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x05, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif
    #ifdef __RE5_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x06, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x06, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif
    #ifdef __RC13_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x07, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x07, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x07, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif
    #ifdef __RB3_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x08, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x08, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif
    #ifdef __RF12_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_12, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x09, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_12, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x09, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_12, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x09, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif
    #ifdef __RC4_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0A, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0A, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0A, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif
    #ifdef __RD15_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_15, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_15, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0B, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_15, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif
    #ifdef __RG0_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0C, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0C, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif
    #ifdef __RA15_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_15, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0D, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_15, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0D, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_15, PORT_A, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0D, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif
    #ifdef __RF7_CN
    #ifdef HAL_LL_U3RXR_ADDRESS
    { PIN_7, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_U3RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI1R_ADDRESS
    { PIN_7, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0F, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_SDI1R_ADDRESS },
    #endif
    #ifdef HAL_LL_SDI2R_ADDRESS
    { PIN_7, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO , 0x0F, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_SDI2R_ADDRESS },
    #endif
    #endif

    #ifdef __RD1_CN
    #ifdef HAL_LL_U4RXR_ADDRESS
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x00, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_U4RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U5RXR_ADDRESS
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x00, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_U5RXR_ADDRESS },
    #endif
    #endif
    #ifdef __RG9_CN
    #ifdef HAL_LL_U4RXR_ADDRESS
    { PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x01, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_U4RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U5RXR_ADDRESS
    { PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x01, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_U5RXR_ADDRESS },
    #endif
    #endif
    #ifdef __RB14_CN
    #ifdef HAL_LL_U4RXR_ADDRESS
    { PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_U4RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U5RXR_ADDRESS
    { PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x02, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_U5RXR_ADDRESS },
    #endif
    #endif
    #ifdef __RD0_CN
    #ifdef HAL_LL_U4RXR_ADDRESS
    { PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x03, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_U4RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U5RXR_ADDRESS
    { PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x03, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_U5RXR_ADDRESS },
    #endif
    #endif
    #ifdef __RD8_CN
    #ifdef HAL_LL_U4RXR_ADDRESS
    { PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x04, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_U4RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U5RXR_ADDRESS
    { PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_U5RXR_ADDRESS },
    #endif
    #endif
    #ifdef __RB6_CN
    #ifdef HAL_LL_U4RXR_ADDRESS
    { PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x05, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_U4RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U5RXR_ADDRESS
    { PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x05, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_U5RXR_ADDRESS },
    #endif
    #endif
    #ifdef __RD5_CN
    #ifdef HAL_LL_U4RXR_ADDRESS
    { PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x06, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_U4RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U5RXR_ADDRESS
    { PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x06, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_U5RXR_ADDRESS },
    #endif
    #endif
    #ifdef __RB2_CN
    #ifdef HAL_LL_U4RXR_ADDRESS
    { PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x07, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_U4RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U5RXR_ADDRESS
    { PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x07, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_U5RXR_ADDRESS },
    #endif
    #endif
    #ifdef __RF3_CN
    #ifdef HAL_LL_U4RXR_ADDRESS
    { PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x08, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_U4RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U5RXR_ADDRESS
    { PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x08, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_U5RXR_ADDRESS },
    #endif
    #endif
    #ifdef __RF13_CN
    #ifdef HAL_LL_U4RXR_ADDRESS
    { PIN_13, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x09, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_U4RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U5RXR_ADDRESS
    { PIN_13, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x09, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_U5RXR_ADDRESS },
    #endif
    #endif
    #ifdef __RF2_CN
    #ifdef HAL_LL_U4RXR_ADDRESS
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_U4RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U5RXR_ADDRESS
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_U5RXR_ADDRESS },
    #endif
    #endif
    #ifdef __RC2_CN
    #ifdef HAL_LL_U4RXR_ADDRESS
    { PIN_2, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0C, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_U4RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U5RXR_ADDRESS
    { PIN_2, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0C, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_U5RXR_ADDRESS },
    #endif
    #endif
    #ifdef __RE8_CN
    #ifdef HAL_LL_U4RXR_ADDRESS
    { PIN_8, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0D, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_U4RXR_ADDRESS },
    #endif
    #ifdef HAL_LL_U5RXR_ADDRESS
    { PIN_8, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART ,     0x0D, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_U5RXR_ADDRESS },
    #endif
    #endif

    { HAL_LL_PIN_NC, HAL_LL_PORT_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_MODULE_ERROR, HAL_LL_MODULE_ERROR }
};

/*!< @brief PPS OUTPUT FUNCTIONS */
static const hal_ll_pps_pin_map_t hal_ll_pps_output_map[] =
{
    #ifdef __RD2_CN
    #ifdef HAL_LL_RPD2R_ADDRESS
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPD2R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD2R_ADDRESS
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPD2R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD2R_ADDRESS
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPD2R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD2R_ADDRESS
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPD2R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD2R_ADDRESS
    { PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPD2R_ADDRESS },
    #endif
    #endif
    #ifdef __RG8_CN
    #ifdef HAL_LL_RPG8R_ADDRESS
    { PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPG8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG8R_ADDRESS
    { PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPG8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG8R_ADDRESS
    { PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPG8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG8R_ADDRESS
    { PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPG8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG8R_ADDRESS
    { PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPG8R_ADDRESS },
    #endif
    #endif
    #ifdef __RF4_CN
    #ifdef HAL_LL_RPF4R_ADDRESS
    { PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPF4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF4R_ADDRESS
    { PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPF4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF4R_ADDRESS
    { PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPF4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF4R_ADDRESS
    { PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPF4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF4R_ADDRESS
    { PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPF4R_ADDRESS },
    #endif
    #endif
    #ifdef __RD10_CN
    #ifdef HAL_LL_RPD10R_ADDRESS
    { PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPD10R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD10R_ADDRESS
    { PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPD10R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD10R_ADDRESS
    { PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPD10R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD10R_ADDRESS
    { PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPD10R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD10R_ADDRESS
    { PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPD10R_ADDRESS },
    #endif
    #endif
    #ifdef __RF1_CN
    #ifdef HAL_LL_RPF1R_ADDRESS
    { PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPF1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF1R_ADDRESS
    { PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPF1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF1R_ADDRESS
    { PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPF1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF1R_ADDRESS
    { PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPF1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF1R_ADDRESS
    { PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPF1R_ADDRESS },
    #endif
    #endif
    #ifdef __RB9_CN
    #ifdef HAL_LL_RPB9R_ADDRESS
    { PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPB9R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB9R_ADDRESS
    { PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPB9R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB9R_ADDRESS
    { PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPB9R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB9R_ADDRESS
    { PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPB9R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB9R_ADDRESS
    { PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPB9R_ADDRESS },
    #endif
    #endif
    #ifdef __RB10_CN
    #ifdef HAL_LL_RPB10R_ADDRESS
    { PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPB10R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB10R_ADDRESS
    { PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPB10R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB10R_ADDRESS
    { PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPB10R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB10R_ADDRESS
    { PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPB10R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB10R_ADDRESS
    { PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPB10R_ADDRESS },
    #endif
    #endif
    #ifdef __RC14_CN
    #ifdef HAL_LL_RPC14R_ADDRESS
    { PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPC14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC14R_ADDRESS
    { PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPC14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC14R_ADDRESS
    { PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPC14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC14R_ADDRESS
    { PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPC14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC14R_ADDRESS
    { PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPC14R_ADDRESS },
    #endif
    #endif
    #ifdef __RB5_CN
    #ifdef HAL_LL_RPB5R_ADDRESS
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPB5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB5R_ADDRESS
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPB5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB5R_ADDRESS
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPB5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB5R_ADDRESS
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPB5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB5R_ADDRESS
    { PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPB5R_ADDRESS },
    #endif
    #endif
    #ifdef __RC1_CN
    #ifdef HAL_LL_RPC1R_ADDRESS
    { PIN_1, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPC1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC1R_ADDRESS
    { PIN_1, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPC1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC1R_ADDRESS
    { PIN_1, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPC1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC1R_ADDRESS
    { PIN_1, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPC1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC1R_ADDRESS
    { PIN_1, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPC1R_ADDRESS },
    #endif
    #endif
    #ifdef __RD14_CN
    #ifdef HAL_LL_RPD14R_ADDRESS
    { PIN_14, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPD14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD14R_ADDRESS
    { PIN_14, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPD14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD14R_ADDRESS
    { PIN_14, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPD14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD14R_ADDRESS
    { PIN_14, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPD14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD14R_ADDRESS
    { PIN_14, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPD14R_ADDRESS },
    #endif
    #endif
    #ifdef __RG1_CN
    #ifdef HAL_LL_RPG1R_ADDRESS
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPG1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG1R_ADDRESS
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPG1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG1R_ADDRESS
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPG1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG1R_ADDRESS
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPG1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG1R_ADDRESS
    { PIN_1, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPG1R_ADDRESS },
    #endif
    #endif
    #ifdef __RA14_CN
    #ifdef HAL_LL_RPA14R_ADDRESS
    { PIN_14, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPA14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPA14R_ADDRESS
    { PIN_14, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPA14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPA14R_ADDRESS
    { PIN_14, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPA14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPA14R_ADDRESS
    { PIN_14, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPA14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPA14R_ADDRESS
    { PIN_14, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPA14R_ADDRESS },
    #endif
    #endif

    #ifdef __RD3_CN
    #ifdef HAL_LL_RPD3R_ADDRESS
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD3R_ADDRESS
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPD3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD3R_ADDRESS
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPD3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD3R_ADDRESS
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD3R_ADDRESS
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPD3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD3R_ADDRESS
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPD3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD3R_ADDRESS
    { PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPD3R_ADDRESS },
    #endif
    #endif
    #ifdef __RG7_CN
    #ifdef HAL_LL_RPG7R_ADDRESS
    { PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPG7R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG7R_ADDRESS
    { PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPG7R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG7R_ADDRESS
    { PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPG7R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG7R_ADDRESS
    { PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPG7R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG7R_ADDRESS
    { PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPG7R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG7R_ADDRESS
    { PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPG7R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG7R_ADDRESS
    { PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPG7R_ADDRESS },
    #endif
    #endif
    #ifdef __RF5_CN
    #ifdef HAL_LL_RPF5R_ADDRESS
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF5R_ADDRESS
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPF5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF5R_ADDRESS
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPF5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF5R_ADDRESS
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF5R_ADDRESS
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPF5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF5R_ADDRESS
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPF5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF5R_ADDRESS
    { PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPF5R_ADDRESS },
    #endif
    #endif
    #ifdef __RD11_CN
    #ifdef HAL_LL_RPD11R_ADDRESS
    { PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD11R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD11R_ADDRESS
    { PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPD11R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD11R_ADDRESS
    { PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPD11R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD11R_ADDRESS
    { PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD11R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD11R_ADDRESS
    { PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPD11R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD11R_ADDRESS
    { PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPD11R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD11R_ADDRESS
    { PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPD11R_ADDRESS },
    #endif
    #endif
    #ifdef __RF0_CN
    #ifdef HAL_LL_RPF0R_ADDRESS
    { PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF0R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF0R_ADDRESS
    { PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPF0R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF0R_ADDRESS
    { PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPF0R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF0R_ADDRESS
    { PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF0R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF0R_ADDRESS
    { PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPF0R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF0R_ADDRESS
    { PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPF0R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF0R_ADDRESS
    { PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPF0R_ADDRESS },
    #endif
    #endif
    #ifdef __RB1_CN
    #ifdef HAL_LL_RPB1R_ADDRESS
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPB1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB1R_ADDRESS
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPB1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB1R_ADDRESS
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPB1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB1R_ADDRESS
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPB1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB1R_ADDRESS
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPB1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB1R_ADDRESS
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPB1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB1R_ADDRESS
    { PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPB1R_ADDRESS },
    #endif
    #endif
    #ifdef __RE5_CN
    #ifdef HAL_LL_RPE5R_ADDRESS
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPE5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE5R_ADDRESS
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPE5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE5R_ADDRESS
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPE5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE5R_ADDRESS
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPE5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE5R_ADDRESS
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPE5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE5R_ADDRESS
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPE5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE5R_ADDRESS
    { PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPE5R_ADDRESS },
    #endif
    #endif
    #ifdef __RC13_CN
    #ifdef HAL_LL_RPC13R_ADDRESS
    { PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPC13R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC13R_ADDRESS
    { PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPC13R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC13R_ADDRESS
    { PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPC13R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC13R_ADDRESS
    { PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPC13R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC13R_ADDRESS
    { PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPC13R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC13R_ADDRESS
    { PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPC13R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC13R_ADDRESS
    { PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPC13R_ADDRESS },
    #endif
    #endif
    #ifdef __RB3_CN
    #ifdef HAL_LL_RPB3R_ADDRESS
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPB3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB3R_ADDRESS
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPB3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB3R_ADDRESS
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPB3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB3R_ADDRESS
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPB3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB3R_ADDRESS
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPB3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB3R_ADDRESS
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPB3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB3R_ADDRESS
    { PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPB3R_ADDRESS },
    #endif
    #endif
    #ifdef __RF3_CN
    #ifdef HAL_LL_RPF3R_ADDRESS
    { PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF3R_ADDRESS
    { PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPF3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF3R_ADDRESS
    { PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPF3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF3R_ADDRESS
    { PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF3R_ADDRESS
    { PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPF3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF3R_ADDRESS
    { PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPF3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF3R_ADDRESS
    { PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPF3R_ADDRESS },
    #endif

    #ifdef HAL_LL_RPF3R_ADDRESS
    { PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPF3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF3R_ADDRESS
    { PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF3R_ADDRESS
    { PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPF3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF3R_ADDRESS
    { PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF3R_ADDRESS },
    #endif
    #endif
    #ifdef __RC4_CN
    #ifdef HAL_LL_RPC4R_ADDRESS
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPC4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC4R_ADDRESS
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPC4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC4R_ADDRESS
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPC4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC4R_ADDRESS
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPC4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC4R_ADDRESS
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPC4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC4R_ADDRESS
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPC4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC4R_ADDRESS
    { PIN_4, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPC4R_ADDRESS },
    #endif
    #endif
    #ifdef __RD15_CN
    #ifdef HAL_LL_RPD15R_ADDRESS
    { PIN_15, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD15R_ADDRESS
    { PIN_15, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPD15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD15R_ADDRESS
    { PIN_15, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPD15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD15R_ADDRESS
    { PIN_15, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD15R_ADDRESS
    { PIN_15, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPD15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD15R_ADDRESS
    { PIN_15, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPD15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD15R_ADDRESS
    { PIN_15, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPD15R_ADDRESS },
    #endif
    #endif
    #ifdef __RG0_CN
    #ifdef HAL_LL_RPC4R_ADDRESS
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPC4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC4R_ADDRESS
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPC4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC4R_ADDRESS
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPC4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC4R_ADDRESS
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPC4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC4R_ADDRESS
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPC4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC4R_ADDRESS
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPC4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC4R_ADDRESS
    { PIN_0, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPC4R_ADDRESS },
    #endif
    #endif
    #ifdef __RA15_CN
    #ifdef HAL_LL_RPA15R_ADDRESS
    { PIN_15, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x01, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPA15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPA15R_ADDRESS
    { PIN_15, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x03, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPA15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPA15R_ADDRESS
    { PIN_15, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPA15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPA15R_ADDRESS
    { PIN_15, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPA15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPA15R_ADDRESS
    { PIN_15, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x06, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPA15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPA15R_ADDRESS
    { PIN_15, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0E, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPA15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPA15R_ADDRESS
    { PIN_15, PORT_A, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0F, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPA15R_ADDRESS },
    #endif
    #endif

    #ifdef __RD9_CN
    #ifdef HAL_LL_RPD9R_ADDRESS
    { PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPD9R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD9R_ADDRESS
    { PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPD9R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD9R_ADDRESS
    { PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPD9R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD9R_ADDRESS
    { PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD9R_ADDRESS },
    #endif
    #endif
    #ifdef __RG6_CN
    #ifdef HAL_LL_RPG6R_ADDRESS
    { PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPG6R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG6R_ADDRESS
    { PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPG6R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG6R_ADDRESS
    { PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPG6R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPG6R_ADDRESS
    { PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPG6R_ADDRESS },
    #endif
    #endif
    #ifdef __RB8_CN
    #ifdef HAL_LL_RPB8R_ADDRESS
    { PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPB8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB8R_ADDRESS
    { PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPB8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB8R_ADDRESS
    { PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPB8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB8R_ADDRESS
    { PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPB8R_ADDRESS },
    #endif
    #endif
    #ifdef __RB15_CN
    #ifdef HAL_LL_RPB15R_ADDRESS
    { PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPB15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB15R_ADDRESS
    { PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPB15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB15R_ADDRESS
    { PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPB15R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB15R_ADDRESS
    { PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPB15R_ADDRESS },
    #endif
    #endif
    #ifdef __RD4_CN
    #ifdef HAL_LL_RPD4R_ADDRESS
    { PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPD4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD4R_ADDRESS
    { PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPD4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD4R_ADDRESS
    { PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPD4R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD4R_ADDRESS
    { PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD4R_ADDRESS },
    #endif
    #endif
    #ifdef __RB0_CN
    #ifdef HAL_LL_RPB0R_ADDRESS
    { PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPB0R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB0R_ADDRESS
    { PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPB0R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB0R_ADDRESS
    { PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPB0R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB0R_ADDRESS
    { PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPB0R_ADDRESS },
    #endif
    #endif
    #ifdef __RE3_CN
    #ifdef HAL_LL_RPE3R_ADDRESS
    { PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPE3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE3R_ADDRESS
    { PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPE3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE3R_ADDRESS
    { PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPE3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE3R_ADDRESS
    { PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPE3R_ADDRESS },
    #endif
    #endif
    #ifdef __RB7_CN
    #ifdef HAL_LL_RPB7R_ADDRESS
    { PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPB7R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB7R_ADDRESS
    { PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPB7R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB7R_ADDRESS
    { PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPB7R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB7R_ADDRESS
    { PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPB7R_ADDRESS },
    #endif
    #endif
    #ifdef __RB2_CN
    #ifdef HAL_LL_RPB2R_ADDRESS
    { PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPB2R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB2R_ADDRESS
    { PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPB2R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB2R_ADDRESS
    { PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPB2R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB2R_ADDRESS
    { PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPB2R_ADDRESS },
    #endif
    #endif
    #ifdef __RF12_CN
    #ifdef HAL_LL_RPF12R_ADDRESS
    { PIN_12, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPF12R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF12R_ADDRESS
    { PIN_12, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPF12R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF12R_ADDRESS
    { PIN_12, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPF12R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF12R_ADDRESS
    { PIN_12, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF12R_ADDRESS },
    #endif
    #endif
    #ifdef __RD12_CN
    #ifdef HAL_LL_RPD12R_ADDRESS
    { PIN_12, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPD12R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD12R_ADDRESS
    { PIN_12, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPD12R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD12R_ADDRESS
    { PIN_12, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPD12R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD12R_ADDRESS
    { PIN_12, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD12R_ADDRESS },
    #endif
    #endif
    #ifdef __RF8_CN
    #ifdef HAL_LL_RPF8R_ADDRESS
    { PIN_8, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPF8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF8R_ADDRESS
    { PIN_8, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPF8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF8R_ADDRESS
    { PIN_8, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPF8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF8R_ADDRESS
    { PIN_8, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF8R_ADDRESS },
    #endif
    #endif
    #ifdef __RC3_CN
    #ifdef HAL_LL_RPC3R_ADDRESS
    { PIN_3, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPC3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC3R_ADDRESS
    { PIN_3, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPC3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC3R_ADDRESS
    { PIN_3, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPC3R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC3R_ADDRESS
    { PIN_3, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPC3R_ADDRESS },
    #endif
    #endif
    #ifdef __RE9_CN
    #ifdef HAL_LL_RPE9R_ADDRESS
    { PIN_9, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x02, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPE9R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE9R_ADDRESS
    { PIN_9, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPE9R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE9R_ADDRESS
    { PIN_9, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPE9R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE9R_ADDRESS
    { PIN_9, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPE9R_ADDRESS },
    #endif
    #endif

    #ifdef __RD1_CN
    #ifdef HAL_LL_RPD1R_ADDRESS
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPD1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD1R_ADDRESS
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD1R_ADDRESS
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPD1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD1R_ADDRESS
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD1R_ADDRESS },
    #endif
    #endif
    #ifdef __RG9_CN
    #ifdef HAL_LL_RPD1R_ADDRESS
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPD1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD1R_ADDRESS
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD1R_ADDRESS
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPD1R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD1R_ADDRESS
    { PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD1R_ADDRESS },
    #endif
    #endif
    #ifdef __RB14_CN
    #ifdef HAL_LL_RPB14R_ADDRESS
    { PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPB14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB14R_ADDRESS
    { PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPB14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB14R_ADDRESS
    { PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPB14R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB14R_ADDRESS
    { PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPB14R_ADDRESS },
    #endif
    #endif
    #ifdef __RD0_CN
    #ifdef HAL_LL_RPD0R_ADDRESS
    { PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPD0R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD0R_ADDRESS
    { PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD0R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD0R_ADDRESS
    { PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPD0R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD0R_ADDRESS
    { PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD0R_ADDRESS },
    #endif
    #endif
    #ifdef __RD8_CN
    #ifdef HAL_LL_RPD8R_ADDRESS
    { PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPD8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD8R_ADDRESS
    { PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD8R_ADDRESS
    { PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPD8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD8R_ADDRESS
    { PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD8R_ADDRESS },
    #endif
    #endif
    #ifdef __RB6_CN
    #ifdef HAL_LL_RPB6R_ADDRESS
    { PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPB6R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB6R_ADDRESS
    { PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPB6R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB6R_ADDRESS
    { PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPB6R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPB6R_ADDRESS
    { PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPB6R_ADDRESS },
    #endif
    #endif
    #ifdef __RD5_CN
    #ifdef HAL_LL_RPD5R_ADDRESS
    { PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPD5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD5R_ADDRESS
    { PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD5R_ADDRESS
    { PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPD5R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPD5R_ADDRESS
    { PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPD5R_ADDRESS },
    #endif
    #endif
    #ifdef __RF6_CN
    #ifdef HAL_LL_RPF6R_ADDRESS
    { PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPF6R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF6R_ADDRESS
    { PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF6R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF6R_ADDRESS
    { PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPF6R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF6R_ADDRESS
    { PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF6R_ADDRESS },
    #endif
    #endif
    #ifdef __RF13_CN
    #ifdef HAL_LL_RPF13R_ADDRESS
    { PIN_13, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPF13R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF13R_ADDRESS
    { PIN_13, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF13R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF13R_ADDRESS
    { PIN_13, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPF13R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF13R_ADDRESS
    { PIN_13, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF13R_ADDRESS },
    #endif
    #endif
    #ifdef __RC2_CN
    #ifdef HAL_LL_RPC2R_ADDRESS
    { PIN_2, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPC2R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC2R_ADDRESS
    { PIN_2, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPC2R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC2R_ADDRESS
    { PIN_2, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPC2R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPC2R_ADDRESS
    { PIN_2, PORT_C, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPC2R_ADDRESS },
    #endif
    #endif
    #ifdef __RE8_CN
    #ifdef HAL_LL_RPE8R_ADDRESS
    { PIN_8, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPE8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE8R_ADDRESS
    { PIN_8, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPE8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE8R_ADDRESS
    { PIN_8, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPE8R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPE8R_ADDRESS
    { PIN_8, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPE8R_ADDRESS },
    #endif
    #endif
    #ifdef __RF2_CN
    #ifdef HAL_LL_RPF2R_ADDRESS
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART,     0x04, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPF2R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF2R_ADDRESS
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0C, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF2R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF2R_ADDRESS
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM,      0x0B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPF2R_ADDRESS },
    #endif
    #ifdef HAL_LL_RPF2R_ADDRESS
    { PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x08, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPF2R_ADDRESS },
    #endif
    #endif

    { HAL_LL_PIN_NC, HAL_LL_PORT_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_MODULE_ERROR, HAL_LL_MODULE_ERROR }
};

#ifdef __cplusplus
}
#endif

#endif // _HAL_LL_PPS_CONNECTION_DEFS_H_
// ------------------------------------------------------------------------- END
