/****************************************************************************
**
** Copyright (C) 2024 MikroElektronika d.o.o.
** Contact: https://www.mikroe.com/contact
**
** This file is part of the mikroSDK package
**
** Commercial License Usage
**
** Licensees holding valid commercial NECTO compilers AI licenses may use this
** file in accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The MikroElektronika Company.
** For licensing terms and conditions see
** https://www.mikroe.com/legal/software-license-agreement.
** For further information use the contact form at
** https://www.mikroe.com/contact.
**
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used for
** non-commercial projects under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** The above copyright notice and this permission notice shall be
** included in all copies or substantial portions of the Software.
**
** THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
** OF MERCHANTABILITY, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED
** TO THE WARRANTIES FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
** IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
** DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
** OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
** OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
**
****************************************************************************/
/*!
 * @file  hal_ll_pps_connection_defs.h
 * @brief This file contains pps maps per chip for LOW LEVEL HAL PPS
 *        implementation for dsPIC33EP512GP806.
 */

#ifndef _HAL_LL_PPS_CONNECTION_DEFS_H_
#define _HAL_LL_PPS_CONNECTION_DEFS_H_

#ifdef __cplusplus
extern "C"
{
#endif

#include "hal_ll_pps_struct_def.h"

/**
 * NOTE:
 * This macro is used for pins that do not have adequate PPS
 * registers according to datasheet.
 */
#define INVALID_PPS_ADDRESS (0) // TODO

// -------------------------------------------------------------

/*!< @brief PPS INPUT FUNCTIONS */
static const hal_ll_pps_pin_map_t hal_ll_pps_input_map[] =
{
    #ifdef UART1_RX_RB0_RPI32
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 32, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB1_RPI33
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 33, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB10_RPI42
    {PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 42, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB11_RPI43
    {PIN_11, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 43, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB12_RPI44
    {PIN_12, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 44, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB13_RPI45
    {PIN_13, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 45, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB14_RPI46
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 46, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB15_RPI47
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 47, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB2_RPI34
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 34, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB3_RPI35
    {PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 35, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB4_RPI36
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 36, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB5_RPI37
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 37, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB6_RPI38
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 38, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB7_RPI39
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 39, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB8_RPI40
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RB9_RPI41
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 41, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RC12_RPI60
    {PIN_12, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 60, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RC13_RPI61
    {PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 61, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RC14_RPI62
    {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 62, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 64, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 65, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD10_RPI74
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 74, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD11_RPI75
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 75, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 66, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 67, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 68, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 69, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 70, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 71, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD8_RPI72
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 72, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RD9_RPI73
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 73, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 80, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RE1_RPI81
    {PIN_1, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 81, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 82, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RE3_RPI83
    {PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 83, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 84, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 85, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RE6_RPI86
    {PIN_6, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 86, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 87, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 96, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 97, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 98, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 99, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 100, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 101, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 102, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 118, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RG7_RPI119
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 119, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 120, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART1_RX_RG9_RPI121
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 121, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR18_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB0_RPI32
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 32, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB1_RPI33
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 33, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB10_RPI42
    {PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 42, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB11_RPI43
    {PIN_11, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 43, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB12_RPI44
    {PIN_12, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 44, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB13_RPI45
    {PIN_13, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 45, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB14_RPI46
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 46, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB15_RPI47
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 47, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB2_RPI34
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 34, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB3_RPI35
    {PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 35, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB4_RPI36
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 36, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB5_RPI37
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 37, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB6_RPI38
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 38, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB7_RPI39
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 39, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB8_RPI40
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 40, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RB9_RPI41
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 41, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RC12_RPI60
    {PIN_12, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 60, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RC13_RPI61
    {PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 61, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RC14_RPI62
    {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 62, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 64, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 65, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD10_RPI74
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 74, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD11_RPI75
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 75, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 66, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 67, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 68, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 69, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 70, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 71, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD8_RPI72
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 72, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RD9_RPI73
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 73, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 80, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RE1_RPI81
    {PIN_1, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 81, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 82, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RE3_RPI83
    {PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 83, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 84, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 85, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RE6_RPI86
    {PIN_6, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 86, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 87, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 96, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 97, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 98, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 99, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 100, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 101, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 102, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 118, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RG7_RPI119
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 119, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 120, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART2_RX_RG9_RPI121
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 121, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPINR19_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB0_RPI32
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 32, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB1_RPI33
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 33, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB10_RPI42
    {PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 42, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB11_RPI43
    {PIN_11, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 43, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB12_RPI44
    {PIN_12, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 44, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB13_RPI45
    {PIN_13, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 45, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB14_RPI46
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 46, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB15_RPI47
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 47, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB2_RPI34
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 34, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB3_RPI35
    {PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 35, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB4_RPI36
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 36, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB5_RPI37
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 37, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB6_RPI38
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 38, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB7_RPI39
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 39, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB8_RPI40
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 40, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RB9_RPI41
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 41, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RC12_RPI60
    {PIN_12, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 60, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RC13_RPI61
    {PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 61, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RC14_RPI62
    {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 62, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 64, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 65, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD10_RPI74
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 74, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD11_RPI75
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 75, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 66, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 67, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 68, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 69, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 70, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 71, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD8_RPI72
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 72, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RD9_RPI73
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 73, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 80, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RE1_RPI81
    {PIN_1, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 81, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 82, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RE3_RPI83
    {PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 83, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 84, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 85, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RE6_RPI86
    {PIN_6, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 86, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 87, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 96, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 97, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 98, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 99, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 100, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 101, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 102, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 118, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RG7_RPI119
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 119, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 120, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART3_RX_RG9_RPI121
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 121, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR27_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB0_RPI32
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 32, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB1_RPI33
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 33, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB10_RPI42
    {PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 42, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB11_RPI43
    {PIN_11, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 43, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB12_RPI44
    {PIN_12, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 44, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB13_RPI45
    {PIN_13, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 45, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB14_RPI46
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 46, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB15_RPI47
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 47, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB2_RPI34
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 34, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB3_RPI35
    {PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 35, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB4_RPI36
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 36, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB5_RPI37
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 37, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB6_RPI38
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 38, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB7_RPI39
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 39, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB8_RPI40
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 40, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RB9_RPI41
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 41, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RC12_RPI60
    {PIN_12, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 60, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RC13_RPI61
    {PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 61, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RC14_RPI62
    {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 62, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 64, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 65, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD10_RPI74
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 74, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD11_RPI75
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 75, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 66, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 67, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 68, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 69, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 70, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 71, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD8_RPI72
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 72, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RD9_RPI73
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 73, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 80, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RE1_RPI81
    {PIN_1, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 81, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 82, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RE3_RPI83
    {PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 83, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 84, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 85, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RE6_RPI86
    {PIN_6, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 86, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 87, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 96, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 97, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 98, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 99, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 100, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 101, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 102, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 118, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RG7_RPI119
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 119, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 120, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef UART4_RX_RG9_RPI121
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 121, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR28_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB0_RPI32
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 32, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB1_RPI33
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 33, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB10_RPI42
    {PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 42, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB11_RPI43
    {PIN_11, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 43, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB12_RPI44
    {PIN_12, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 44, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB13_RPI45
    {PIN_13, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 45, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB14_RPI46
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 46, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB15_RPI47
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 47, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB2_RPI34
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 34, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB3_RPI35
    {PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 35, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB4_RPI36
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 36, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB5_RPI37
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 37, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB6_RPI38
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 38, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB7_RPI39
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 39, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB8_RPI40
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 40, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RB9_RPI41
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 41, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RC12_RPI60
    {PIN_12, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 60, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RC13_RPI61
    {PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 61, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RC14_RPI62
    {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 62, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 64, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 65, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD10_RPI74
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 74, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD11_RPI75
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 75, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 66, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 67, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 68, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 69, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 70, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 71, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD8_RPI72
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 72, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RD9_RPI73
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 73, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 80, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RE1_RPI81
    {PIN_1, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 81, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 82, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RE3_RPI83
    {PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 83, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 84, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 85, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RE6_RPI86
    {PIN_6, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 86, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 87, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 96, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 97, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 98, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 99, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 100, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 101, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 102, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 118, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RG7_RPI119
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 119, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 120, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI1_MISO_RG9_RPI121
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 121, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPINR20_REG_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB0_RPI32
    // {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 32, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB1_RPI33
    // {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 33, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB10_RPI42
    // {PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 42, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB11_RPI43
    // {PIN_11, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 43, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB12_RPI44
    // {PIN_12, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 44, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB13_RPI45
    // {PIN_13, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 45, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB14_RPI46
    // {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 46, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB15_RPI47
    // {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 47, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB2_RPI34
    // {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 34, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB3_RPI35
    // {PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 35, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB4_RPI36
    // {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 36, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB5_RPI37
    // {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 37, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB6_RPI38
    // {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 38, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB7_RPI39
    // {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 39, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB8_RPI40
    // {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 40, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RB9_RPI41
    // {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 41, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RC12_RPI60
    // {PIN_12, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 60, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RC13_RPI61
    // {PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 61, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RC14_RPI62
    // {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 62, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD0_RP64
    // {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 64, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD1_RP65
    // {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 65, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD10_RPI74
    // {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 74, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD11_RPI75
    // {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 75, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD2_RP66
    // {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 66, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD3_RP67
    // {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 67, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD4_RP68
    // {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 68, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD5_RP69
    // {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 69, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD6_RP70
    // {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 70, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD7_RP71
    // {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 71, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD8_RPI72
    // {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 72, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RD9_RPI73
    // {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 73, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RE0_RP80
    // {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 80, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RE1_RPI81
    // {PIN_1, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 81, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RE2_RP82
    // {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 82, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RE3_RPI83
    // {PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 83, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RE4_RP84
    // {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 84, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RE5_RP85
    // {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 85, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RE6_RPI86
    // {PIN_6, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 86, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RE7_RP87
    // {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 87, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RF0_RP96
    // {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 96, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RF1_RP97
    // {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 97, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RF2_RP98
    // {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 98, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RF3_RP99
    // {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 99, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RF4_RP100
    // {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 100, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RF5_RP101
    // {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 101, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RF6_RP102
    // {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 102, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RG6_RP118
    // {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 118, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RG7_RPI119
    // {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 119, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RG8_RP120
    // {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 120, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI2_MISO_RG9_RPI121
    // {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 121, HAL_LL_PPS_MODULE_INDEX_2, INVALID_PPS_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB0_RPI32
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 32, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB1_RPI33
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 33, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB10_RPI42
    {PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 42, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB11_RPI43
    {PIN_11, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 43, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB12_RPI44
    {PIN_12, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 44, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB13_RPI45
    {PIN_13, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 45, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB14_RPI46
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 46, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB15_RPI47
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 47, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB2_RPI34
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 34, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB3_RPI35
    {PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 35, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB4_RPI36
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 36, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB5_RPI37
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 37, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB6_RPI38
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 38, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB7_RPI39
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 39, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB8_RPI40
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 40, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RB9_RPI41
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 41, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RC12_RPI60
    {PIN_12, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 60, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RC13_RPI61
    {PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 61, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RC14_RPI62
    {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 62, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 64, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 65, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD10_RPI74
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 74, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD11_RPI75
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 75, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 66, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 67, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 68, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 69, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 70, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 71, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD8_RPI72
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 72, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RD9_RPI73
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 73, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 80, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RE1_RPI81
    {PIN_1, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 81, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 82, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RE3_RPI83
    {PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 83, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 84, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 85, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RE6_RPI86
    {PIN_6, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 86, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 87, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 96, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 97, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 98, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 99, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 100, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 101, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 102, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 118, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RG7_RPI119
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 119, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 120, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI3_MISO_RG9_RPI121
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 121, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPINR29_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB0_RPI32
    {PIN_0, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 32, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB1_RPI33
    {PIN_1, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 33, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB10_RPI42
    {PIN_10, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 42, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB11_RPI43
    {PIN_11, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 43, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB12_RPI44
    {PIN_12, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 44, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB13_RPI45
    {PIN_13, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 45, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB14_RPI46
    {PIN_14, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 46, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB15_RPI47
    {PIN_15, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 47, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB2_RPI34
    {PIN_2, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 34, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB3_RPI35
    {PIN_3, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 35, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB4_RPI36
    {PIN_4, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 36, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB5_RPI37
    {PIN_5, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 37, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB6_RPI38
    {PIN_6, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 38, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB7_RPI39
    {PIN_7, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 39, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB8_RPI40
    {PIN_8, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 40, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RB9_RPI41
    {PIN_9, PORT_B, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 41, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RC12_RPI60
    {PIN_12, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 60, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RC13_RPI61
    {PIN_13, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 61, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RC14_RPI62
    {PIN_14, PORT_C, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 62, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 64, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 65, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RD10_RPI74
    {PIN_10, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 74, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RD11_RPI75
    {PIN_11, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 75, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 66, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 67, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 68, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 69, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 70, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 71, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RD8_RPI72
    {PIN_8, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 72, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RD9_RPI73
    {PIN_9, PORT_D, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 73, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 80, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RE1_RPI81
    {PIN_1, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 81, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 82, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RE3_RPI83
    {PIN_3, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 83, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 84, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 85, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RE6_RPI86
    {PIN_6, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 86, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 87, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 96, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 97, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 98, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 99, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 100, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 101, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 102, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 118, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RG7_RPI119
    {PIN_7, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 119, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 120, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif
    #ifdef SPI4_MISO_RG9_RPI121
    {PIN_9, PORT_G, HAL_LL_GPIO_DIGITAL_INPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MISO, 121, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPINR31_REG_ADDRESS},
    #endif

    { HAL_LL_PIN_NC, HAL_LL_PORT_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_MODULE_ERROR, HAL_LL_MODULE_ERROR }
};

/*!< @brief PPS OUTPUT FUNCTIONS */
static const hal_ll_pps_pin_map_t hal_ll_pps_output_map[] =
{
    #ifdef UART1_TX_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0001, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0001ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0001, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0001ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0001, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0001ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0001, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0001ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0001ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0001, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0001ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0001, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0001ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0001, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0001ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0001, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0001ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0001, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0001ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0001, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0001ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef UART1_TX_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0001, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x0003ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef UART2_TX_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x0003, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Bul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Bul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Bul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Bul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Bul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Bul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Bul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Bul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Bul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Bul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Bul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef UART3_TX_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001B, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001D, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Dul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001D, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Dul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001D, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Dul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001D, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Dul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Dul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001D, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Dul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001D, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Dul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001D, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Dul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001D, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Dul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001D, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Dul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001D, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, (0x001Dul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef UART4_TX_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_UART, 0x001D, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0005, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0005, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0005, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0005, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0005, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0005, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0005, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0005, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0005, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0005, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0005ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI1_MOSI_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0005, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0006, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0006ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0006, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0006ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0006, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0006ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0006, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0006ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0006ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0006, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0006ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0006, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0006ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0006, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0006ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0006, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0006ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0006, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0006ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0006, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0006ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI1_SCK_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0006, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0008, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0008, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0008, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0008, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0008, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0008, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0008, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0008, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0008, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0008, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0008ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI2_MOSI_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0008, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0009, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0009ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0009, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0009ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0009, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0009ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0009, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0009ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0009ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0009, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0009ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0009, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0009ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0009, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0009ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0009, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0009ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0009, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0009ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0009, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0009ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI2_SCK_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0009, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x001F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x001Ful << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x001F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x001Ful << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x001F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x001Ful << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x001F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x001Ful << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x001Ful << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x001F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x001Ful << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x001F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x001Ful << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x001F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x001Ful << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x001F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x001Ful << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x001F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x001Ful << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x001F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x001Ful << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI3_MOSI_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x001F, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0020, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0020ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0020, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0020ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0020, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0020ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0020, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0020ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0020ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0020, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0020ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0020, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0020ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0020, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0020ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0020, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0020ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0020, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0020ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0020, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0020ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI3_SCK_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0020, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0022, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0022ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0022, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0022ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0022, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0022ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0022, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0022ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0022ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0022, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0022ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0022, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0022ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0022, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0022ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0022, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0022ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0022, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0022ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0022, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, (0x0022ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI4_MOSI_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_MOSI, 0x0022, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0023, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0023ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0023, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0023ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0023, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0023ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0023, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0023ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0023ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0023, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0023ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0023, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0023ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0023, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0023ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0023, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0023ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0023, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0023ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0023, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, (0x0023ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef SPI4_SCK_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_SPI_SCK, 0x0023, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC1_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0010, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC11_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0027, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC13_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0029ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC3_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0012ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC4_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0013, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC5_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0014ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC7_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0016, HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP1_OC9_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0025ul << 8), HAL_LL_PPS_MODULE_INDEX_1, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC11_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0027ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC15_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x002B, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC2_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0011ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC5_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0014ul << 8), HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP2_OC8_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0017, HAL_LL_PPS_MODULE_INDEX_2, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP3_OC1_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0010ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP3_OC14_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x002A, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP3_OC4_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP3_OC5_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0014, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP3_OC6_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0015, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP3_OC7_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0016, HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP3_OC8_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_3, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP4_OC13_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0029, HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP4_OC9_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0025ul << 8), HAL_LL_PPS_MODULE_INDEX_4, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC1_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0010, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC11_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0027, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC13_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0029ul << 8), HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC3_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0012ul << 8), HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC4_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0013, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC5_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0014ul << 8), HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC7_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0016, HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP5_OC9_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0025ul << 8), HAL_LL_PPS_MODULE_INDEX_5, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP6_OC11_RE4_RP84
    {PIN_4, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0027ul << 8), HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP6_OC15_RE5_RP85
    {PIN_5, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x002B, HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP6_OC2_RE7_RP87
    {PIN_7, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0011ul << 8), HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR6_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP6_OC5_RE0_RP80
    {PIN_0, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0014ul << 8), HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR4_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP6_OC8_RE2_RP82
    {PIN_2, PORT_E, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0017, HAL_LL_PPS_MODULE_INDEX_6, HAL_LL_RPOR5_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP7_OC1_RF5_RP101
    {PIN_5, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0010ul << 8), HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP7_OC14_RF4_RP100
    {PIN_4, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x002A, HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR9_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP7_OC4_RF3_RP99
    {PIN_3, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0013ul << 8), HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP7_OC5_RF2_RP98
    {PIN_2, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0014, HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR8_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP7_OC6_RF6_RP102
    {PIN_6, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0015, HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR10_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP7_OC7_RF0_RP96
    {PIN_0, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0016, HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP7_OC8_RF1_RP97
    {PIN_1, PORT_F, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0017ul << 8), HAL_LL_PPS_MODULE_INDEX_7, HAL_LL_RPOR7_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP8_OC13_RG8_RP120
    {PIN_8, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0029, HAL_LL_PPS_MODULE_INDEX_8, HAL_LL_RPOR14_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP8_OC9_RG6_RP118
    {PIN_6, PORT_G, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0025ul << 8), HAL_LL_PPS_MODULE_INDEX_8, HAL_LL_RPOR13_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP9_OC1_RD0_RP64
    {PIN_0, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0010, HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP9_OC11_RD6_RP70
    {PIN_6, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0027, HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP9_OC13_RD7_RP71
    {PIN_7, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0029ul << 8), HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR3_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP9_OC3_RD1_RP65
    {PIN_1, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0012ul << 8), HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR0_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP9_OC4_RD2_RP66
    {PIN_2, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0013, HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP9_OC5_RD3_RP67
    {PIN_3, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0014ul << 8), HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR1_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP9_OC7_RD4_RP68
    {PIN_4, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, 0x0016, HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR2_REG_ADDRESS},
    #endif
    #ifdef PWM_CCP9_OC9_RD5_RP69
    {PIN_5, PORT_D, HAL_LL_GPIO_DIGITAL_OUTPUT, HAL_LL_PPS_FUNCTIONALITY_PWM, (0x0025ul << 8), HAL_LL_PPS_MODULE_INDEX_9, HAL_LL_RPOR2_REG_ADDRESS},
    #endif

    { HAL_LL_PIN_NC, HAL_LL_PORT_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_PIN_NC, HAL_LL_MODULE_ERROR, HAL_LL_MODULE_ERROR }
};

#ifdef __cplusplus
}
#endif

#endif // _HAL_LL_PPS_CONNECTION_DEFS_H_
// ------------------------------------------------------------------------- END
